@@ -134,10 +134,10 @@ class connector:
 			reply = requests.post(url, json=kwargs['body'], headers=self.head)
 			reply.raise_for_status()
 			if self.verbose == True:
-				print(self.GREEN + "Success GET on " + url + self.DEFAULT)
+				print(self.GREEN + "Success POST on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), name='error.json')
-			print(self.RED + err + 'on POST ' + url + self.DEFAULT)
+			print(self.RED + str(err) + 'on POST ' + url + self.DEFAULT)
 		return (json.loads(reply.text))
 
 	def patch(self, endpoint, **kwargs):
@@ -146,7 +146,7 @@ class connector:
 			reply = requests.patch(url, json=kwargs['body'], headers=self.head, )
 			reply.raise_for_status()
 			if self.verbose == True:
-				print(self.GREEN + "Success POST on " + url + self.DEFAULT)
+				print(self.GREEN + "Success PATCH on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
 			self.put_in_file(json.loads(reply.text), name='error.json')
 			print(self.RED + str(err) + 'on PATCH ' + url + self.DEFAULT)
